@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
-our $DATE = '2016-02-14'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-02-22'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -197,8 +197,13 @@ sub munge_module {
                 );
                 $self->log_fatal(["Can't lcpan mod2dist: %s - %res", $res->[0], $res->[1]])
                     unless $res->[0] == 200;
-                for (values %$res) {
-                    $self->{_dists}{$_} = 0;
+                if (ref $res->[2]) {
+                    for (values %{$res->[2]}) {
+                        $self->{_dists}{$_} = 0;
+                    }
+                } else {
+                    # single result
+                    $self->{_dists}{$res->[2]} = 0;
                 }
             }
         }
@@ -250,7 +255,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.18 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2016-02-14.
+This document describes version 0.19 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2016-02-22.
 
 =head1 SYNOPSIS
 
